#
# spec file for package freeipmi
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (c) 2003-2008 FreeIPMI Core Team
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define name freeipmi
%define version 1.4.9
%define srcversion %{version}
%if %{?_with_debug:1}%{!?_with_debug:0}
%define release 1.debug%{?dist}
%else
%define release 1%{?dist}
%endif

%{!?_initddir: %global _initddir %{_sysconfdir}/init.d}

Name:           %{name}
Version:        %{version}
Release:        5.5
Url:            http://www.gnu.org/software/freeipmi/
Source0:        http://ftp.gnu.org/gnu/freeipmi/%{name}-%{srcversion}.tar.gz
Source4:        http://ftp.gnu.org/gnu/freeipmi/%{name}-%{srcversion}.tar.gz.sig
Source5:        %{name}.keyring
Source1:        bmc-watchdog.service
Source2:        ipmidetectd.service
Source3:        ipmiseld.service
Summary:        FreeIPMI
License:        GPL-3.0+
Group:          System/Management
BuildRequires:  automake
BuildRequires:  libgcrypt-devel
BuildRequires:  libtool
BuildRequires:  pkg-config
BuildRequires:  texinfo
%if 0%{?suse_version} > 1010
BuildRequires:  fdupes
%endif
%if 0%{?suse_version} >=1230
BuildRequires:  pkgconfig(systemd)
%endif
%if 0%{?fedora_version} == 20 || 0%{?rhel_version} >= 700
BuildRequires:  perl-Exporter
%endif

Obsoletes:      freeipmi-ipmimonitoring < %{version}
Provides:       freeipmi-ipmimonitoring = %{version}
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
Requires(post): info
Requires(preun): info
# Necessary as only those archs implement iopl and friends (#368541)
ExclusiveArch:  %{ix86} x86_64 ia64 alpha

%description
This project provides "Remote-Console" (out-of-band) and
"System Management Software" (in-band) based on Intelligent
Platform Management Interface specification.

%package devel
Summary:        Development package for FreeIPMI
Group:          Development/Tools/Other
Requires:       freeipmi = %{version}

%description devel
Development package for FreeIPMI.  This package includes the FreeIPMI
header files and static libraries.

%package bmc-watchdog
Summary:        FreeIPMI BMC watchdog
Group:          System/Management
%if 0%{?suse_version}
Requires(pre):  %fillup_prereq
%if 0%{?suse_version} >=1230
%{?systemd_requires}
%endif
%endif
Requires:       freeipmi = %{version}
%if 0%{?fedora_version} || 0%{?centos_version} || 0%{?rhel_version} || 0%{?fedora} || 0%{?rhel}
Requires(post): chkconfig
Requires(preun): chkconfig
%endif
Requires:       logrotate

%description bmc-watchdog
Provides a watchdog daemon for OS monitoring and recovery.

%package ipmidetectd
Summary:        IPMI node detection monitoring daemon
Group:          System/Management
Requires:       freeipmi = %{version}
%if 0%{?fedora_version} || 0%{?centos_version} || 0%{?rhel_version} || 0%{?fedora} || 0%{?rhel}
Requires(post): chkconfig
Requires(preun): chkconfig
%endif
%if 0%{?suse_version} >=1230
%{?systemd_requires}
%endif

%description ipmidetectd
This service detects and monitors IPMI nodes.

%if %{?_with_debug:1}%{!?_with_debug:0}
  %define _enable_debug --enable-debug --enable-trace
%endif

%prep
%setup -q -n %{name}-%{srcversion}

%build
%if 0%{?suse_version} >= 1110
aclocal -I config
autoheader
libtoolize --force --automake --copy
autoconf
automake --gnu --include-deps --copy --add-missing
%endif
%if (0%{?fedora_version} > 0 && 0%{?fedora_version} < 21) || 0%{?centos_version} || 0%{?rhel_version}
%define docpath %{_docdir}/%{name}-%{version}
%else
%define docpath %{_docdir}/%{name}
%endif
%configure --program-prefix=%{?_program_prefix:%{_program_prefix}} \
           --docdir=%{docpath} \
           %{?_enable_debug} --disable-static
CFLAGS="%{optflags}" make %{?_smp_mflags}

%install
mkdir -p %{buildroot}

%if 0%{?fedora_version} || 0%{?centos_version} || 0%{?rhel_version} || 0%{?fedora} || 0%{?rhel}
# /etc/rc.d/init.d
mkdir -p %{buildroot}/%{_initddir}
# 'make install' installs to /etc/init.d
# /etc/init.d -> /etc/rc.d/init.d
(cd %{buildroot}/%{_sysconfdir}; ln -s rc.d/init.d init.d)
%endif

%if 0%{?suse_version}
%makeinstall
%else
make install DESTDIR=%{buildroot}
%endif

# Silent build check warning
rm -f %{buildroot}%{_datadir}/doc/packages/freeipmi/INSTALL

%if 0%{?fedora_version} || 0%{?centos_version} || 0%{?rhel_version} || 0%{?fedora} || 0%{?rhel}
# remove /etc/init.d -> /etc/rc.d/init.d
(cd %{buildroot}/%{_sysconfdir}; rm init.d)
%endif

# Add systemd support for openSUSE >= 12.3
%if 0%{?suse_version} >=1230
mkdir -p %{buildroot}%{_unitdir}
%{__install} -m 0644 %{S:1} %{S:2} %{S:3} %{buildroot}%{_unitdir}/
rm -r %{buildroot}%{_initddir}
%endif

# fix coherance problems with associated script filenames
rm -f %{buildroot}%{_infodir}/dir
# kludge to get around rpmlint complaining about 0 length semephore file
mkdir -p %{buildroot}%{_localstatedir}/lib/freeipmi
echo freeipmi > %{buildroot}%{_localstatedir}/lib/freeipmi/ipckey
# Remove .la files
rm -rf %{buildroot}/%{_libdir}/*.la

%if 0%{?suse_version}
mkdir -p %{buildroot}%{_localstatedir}/adm/fillup-templates
mv %{buildroot}%{_sysconfdir}/sysconfig/bmc-watchdog %{buildroot}%{_localstatedir}/adm/fillup-templates/sysconfig.bmc-watchdog
%endif

%if 0%{?suse_version} > 1010
%fdupes $RPM_BUILD_ROOT
%endif

%post
if [ -x /sbin/install-info ]; then
   #/sbin/install-info %{_infodir}/freeipmi.info.gz %{_infodir}/dir
   /sbin/install-info %{_infodir}/freeipmi-faq.info.gz %{_infodir}/dir
fi
/sbin/ldconfig

%preun
if [ $1 = 0 ]; then
   if [ -x /sbin/install-info ]; then
      #/sbin/install-info --delete %{_infodir}/freeipmi.info.gz %{_infodir}/dir
      /sbin/install-info --delete %{_infodir}/freeipmi-faq.info.gz %{_infodir}/dir
   fi
fi

%postun -p /sbin/ldconfig

%post bmc-watchdog
%if 0%{?suse_version}
%{fillup_only}
%endif
%if 0%{?suse_version} >=1230
%service_add_post bmc-watchdog.service
%else
if [ "$1" = 1 ]; then
   if [ -x %{_initddir}/bmc-watchdog ]; then
      /sbin/chkconfig --add bmc-watchdog
      /sbin/chkconfig bmc-watchdog off
   fi
fi
if [ $1 -ge 1 ]; then
   if [ -x %{_initddir}/bmc-watchdog ]; then
      if %{_initddir}/bmc-watchdog status | grep -q running; then
         %{_initddir}/bmc-watchdog restart
      else
         %{_initddir}/bmc-watchdog condrestart
      fi
   fi
fi
%endif

%preun bmc-watchdog
%if 0%{?suse_version} >=1230
%service_del_preun bmc-watchdog.service
%else
#
# Stop bmc-watchdog if it is running
#
if [ "$1" = 0 ]; then
    if [ -x %{_initddir}/bmc-watchdog ]; then
       if %{_initddir}/bmc-watchdog status | grep -q running; then
          %{_initddir}/bmc-watchdog stop
       fi
       /sbin/chkconfig --del bmc-watchdog
    fi
fi
%endif

%post ipmidetectd
%if 0%{?suse_version} >=1230
%service_add_post ipmidetectd.service
%else
if [ "$1" = 1 ]; then
   if [ -x %{_initddir}/ipmidetectd ]; then
      /sbin/chkconfig --add ipmidetectd
      /sbin/chkconfig ipmidetectd off
   fi
fi
if [ $1 -ge 1 ]; then
   if [ -x %{_initddir}/ipmidetectd ]; then
      if %{_initddir}/ipmidetectd status | grep -q running; then
         %{_initddir}/ipmidetectd restart
      else
         %{_initddir}/ipmidetectd condrestart
      fi
   fi
fi
%endif

%preun ipmidetectd
%if 0%{?suse_version} >=1230
%service_del_preun ipmidetectd.service
%else
#
# Stop ipmidetectd if it is running
#
if [ "$1" = 0 ]; then
    if [ -x %{_initddir}/ipmidetectd ]; then
       if %{_initddir}/ipmidetectd status | grep -q running; then
          %{_initddir}/ipmidetectd stop
       fi
       /sbin/chkconfig --del ipmidetectd
    fi
fi
%endif

%files
%defattr(-,root,root)
# %attr(0444,root,root) %config(noreplace) %{_sysconfdir}/ipmi_monitoring_sensors.conf
%config(noreplace) %{_sysconfdir}/freeipmi/freeipmi.conf
%dir %{_sysconfdir}/freeipmi
%config %{_sysconfdir}/freeipmi/freeipmi_interpret_sel.conf
%config %{_sysconfdir}/freeipmi/freeipmi_interpret_sensor.conf
%config %{_sysconfdir}/freeipmi/ipmidetect.conf
%config %{_sysconfdir}/freeipmi/libipmiconsole.conf
%doc AUTHORS
%doc COPYING
%doc ChangeLog
%doc ChangeLog.0
# doc INSTALL
%doc NEWS
%doc README
%doc TODO
%doc %{_infodir}/*
%doc COPYING.ipmiping
%doc COPYING.ipmipower
%doc COPYING.ipmiconsole
%doc COPYING.ipmimonitoring
%doc COPYING.pstdout
%doc COPYING.ipmidetect
%doc COPYING.ipmi-fru
%doc COPYING.ZRESEARCH
%doc DISCLAIMER.ipmiping
%doc DISCLAIMER.ipmipower
%doc DISCLAIMER.ipmiconsole
%doc DISCLAIMER.ipmidetect
%doc DISCLAIMER.ipmimonitoring
%doc DISCLAIMER.pstdout
%doc DISCLAIMER.ipmi-fru
%doc DISCLAIMER.ipmiping.UC
%doc DISCLAIMER.ipmipower.UC
%doc DISCLAIMER.ipmiconsole.UC
%doc DISCLAIMER.ipmimonitoring.UC
%doc DISCLAIMER.pstdout.UC
%doc DISCLAIMER.ipmidetect.UC
%doc DISCLAIMER.ipmi-fru.UC
%doc doc/freeipmi-coding.txt
%doc doc/freeipmi-hostrange.txt
%doc doc/freeipmi-libraries.txt
%doc doc/freeipmi-bugs-issues-and-workarounds.txt
#%dir %{_docdir}
%if 0%{?fedora_version} == 20
%{docpath}
%endif
%config %{_sysconfdir}/freeipmi/ipmiseld.conf
%if 0%{?suse_version} >=1230
%{_unitdir}/ipmiseld.service
%else
%{_initddir}/ipmiseld
%endif
%{_libdir}/libipmiconsole*so.*
%{_libdir}/libipmidetect*so.*
%{_libdir}/libfreeipmi*so.*
%{_libdir}/libipmimonitoring.so.*
%{_localstatedir}/lib/*
%{_sbindir}/ipmi-config
%{_sbindir}/bmc-config
%{_sbindir}/bmc-info
%{_sbindir}/bmc-device
%{_sbindir}/ipmi-fru
%{_sbindir}/ipmi-locate
%{_sbindir}/ipmi-oem
%{_sbindir}/ipmi-pef-config
%{_sbindir}/pef-config
%{_sbindir}/ipmi-raw
%{_sbindir}/ipmi-sel
%{_sbindir}/ipmiseld
%{_sbindir}/ipmi-sensors
%{_sbindir}/ipmi-sensors-config
%{_sbindir}/ipmiping
%{_sbindir}/ipmipower
%{_sbindir}/ipmiconsole
%{_sbindir}/ipmimonitoring
%{_sbindir}/ipmi-chassis
%{_sbindir}/ipmi-chassis-config
%{_sbindir}/ipmi-dcmi
%{_sbindir}/ipmidetect
%{_sbindir}/ipmi-console
%{_sbindir}/ipmi-detect
%{_sbindir}/ipmi-ping
%{_sbindir}/ipmi-power
%{_sbindir}/rmcp-ping
%{_sbindir}/rmcpping
%{_sbindir}/ipmi-pet
%{_mandir}/man8/bmc-config.8*
%{_mandir}/man5/bmc-config.conf.5*
%{_mandir}/man8/bmc-info.8*
%{_mandir}/man8/bmc-device.8*
%{_mandir}/man8/ipmi-fru.8*
%{_mandir}/man8/ipmi-locate.8*
%{_mandir}/man8/ipmi-pef-config.8*
%{_mandir}/man8/ipmi-config.8*
%{_mandir}/man5/ipmi-config.conf.5*
%{_mandir}/man8/pef-config.8*
%{_mandir}/man8/ipmi-oem.8*
%{_mandir}/man8/ipmi-raw.8*
%{_mandir}/man8/ipmi-sel.8*
%{_mandir}/man8/ipmi-sensors.8*
%{_mandir}/man8/ipmi-sensors-config.8*
%{_mandir}/man8/ipmiping.8*
%{_mandir}/man8/ipmipower.8*
%{_mandir}/man5/ipmipower.conf.5*
%{_mandir}/man8/ipmiconsole.8*
%{_mandir}/man5/ipmiconsole.conf.5*
%{_mandir}/man8/ipmimonitoring.8*
%{_mandir}/man5/ipmi_monitoring_sensors.conf.5*
%{_mandir}/man5/ipmimonitoring_sensors.conf.5*
%{_mandir}/man5/ipmimonitoring.conf.5*
%{_mandir}/man5/libipmimonitoring.conf.5*
%{_mandir}/man8/ipmi-chassis.8*
%{_mandir}/man8/ipmi-chassis-config.8*
%{_mandir}/man8/ipmi-dcmi.8*
%{_mandir}/man8/ipmidetect.8*
%{_mandir}/man5/freeipmi.conf.5*
%{_mandir}/man5/ipmidetect.conf.5*
%{_mandir}/man7/freeipmi.7*
%{_mandir}/man8/rmcp-ping.8*
%{_mandir}/man8/rmcpping.8*
%{_mandir}/man5/freeipmi_interpret_sel.conf.5*
%{_mandir}/man5/freeipmi_interpret_sensor.conf.5*
%{_mandir}/man5/libipmiconsole.conf.5*
%{_mandir}/man5/ipmiseld.conf.5*
%{_mandir}/man8/ipmiseld.8*
%{_mandir}/man8/ipmi-console.8*
%{_mandir}/man8/ipmi-detect.8*
%{_mandir}/man8/ipmi-ping.8*
%{_mandir}/man8/ipmi-power.8*
%{_mandir}/man8/ipmi-pet.8*
%dir %{_localstatedir}/cache/ipmimonitoringsdrcache

%files devel
%defattr(-,root,root)
%{_libdir}/libipmiconsole.so
%{_libdir}/libfreeipmi.so
%{_libdir}/libipmidetect.so
%{_libdir}/libipmimonitoring.so
%{_libdir}/pkgconfig/*
%dir %{_includedir}/freeipmi
%dir %{_includedir}/freeipmi/api
%dir %{_includedir}/freeipmi/cmds
%dir %{_includedir}/freeipmi/debug
%dir %{_includedir}/freeipmi/driver
%dir %{_includedir}/freeipmi/fiid
%dir %{_includedir}/freeipmi/fru
%dir %{_includedir}/freeipmi/interface
%dir %{_includedir}/freeipmi/interpret
%dir %{_includedir}/freeipmi/locate
%dir %{_includedir}/freeipmi/payload
%dir %{_includedir}/freeipmi/record-format
%dir %{_includedir}/freeipmi/sdr
%dir %{_includedir}/freeipmi/sel
%dir %{_includedir}/freeipmi/sensor-read
%dir %{_includedir}/freeipmi/spec
%dir %{_includedir}/freeipmi/templates
%dir %{_includedir}/freeipmi/util

%{_includedir}/ipmiconsole.h
%{_includedir}/ipmidetect.h
%{_includedir}/ipmi_monitoring.h
%{_includedir}/ipmi_monitoring_bitmasks.h
%{_includedir}/ipmi_monitoring_offsets.h
%{_includedir}/freeipmi/*.h
%{_includedir}/freeipmi/api/*.h
%{_includedir}/freeipmi/cmds/*.h
%{_includedir}/freeipmi/debug/*.h
%{_includedir}/freeipmi/driver/*.h
%{_includedir}/freeipmi/fiid/*.h
%{_includedir}/freeipmi/fru/*.h
%{_includedir}/freeipmi/interface/*.h
%{_includedir}/freeipmi/interpret/ipmi-interpret.h
%{_includedir}/freeipmi/locate/*.h
%{_includedir}/freeipmi/payload/ipmi-sol-payload.h
%{_includedir}/freeipmi/record-format/*.h
%{_includedir}/freeipmi/sdr/*.h
%{_includedir}/freeipmi/sel/*.h
%{_includedir}/freeipmi/sensor-read/*.h
%{_includedir}/freeipmi/spec/*.h
%{_includedir}/freeipmi/templates/*.h
%{_includedir}/freeipmi/util/*.h
%{_mandir}/man3/*

%files bmc-watchdog
%defattr(-,root,root)
%doc COPYING.bmc-watchdog
%doc DISCLAIMER.bmc-watchdog
%doc DISCLAIMER.bmc-watchdog.UC
%if 0%{?suse_version} >=1230
%{_unitdir}/bmc-watchdog.service
%else
%config(noreplace) %{_initddir}/bmc-watchdog
%endif
%if 0%{?suse_version}
%attr(0444,root,root) %config(noreplace) %{_localstatedir}/adm/fillup-templates/sysconfig.bmc-watchdog
%else
%attr(0444,root,root) %config(noreplace) %{_sysconfdir}/sysconfig/bmc-watchdog
%endif
# %attr(0444,root,root) %config(noreplace) %{_sysconfdir}/logrotate.d/bmc-watchdog
%{_sbindir}/bmc-watchdog
%{_mandir}/man8/bmc-watchdog.8*
# %dir %{_localstatedir}/log/freeipmi

%files ipmidetectd
%defattr(-,root,root)
%if 0%{?suse_version} >=1230
%{_unitdir}/ipmidetectd.service
%else
%config(noreplace) %{_initddir}/ipmidetectd
%endif
%attr(0444,root,root) %config(noreplace) %{_sysconfdir}/freeipmi/ipmidetectd.conf
%{_sbindir}/ipmidetectd
%{_mandir}/man5/ipmidetectd.conf.5*
%{_mandir}/man8/ipmidetectd.8*

%changelog
* Thu Jun 18 2015 kkaempf@suse.com
- fix Fedora/RHEL builds
* Tue Jun  2 2015 kkaempf@suse.com
- Update to 1.4.9
  o Fix strtol parse corner cases in several commands.
  o Minor documentation fixes.
* Thu Apr  2 2015 mpluskal@suse.com
- Add gpg signature
* Thu Jan  8 2015 kkaempf@suse.com
- Update to 1.4.8
  o Fix segfault in crypt code with libgcrypt versions >= 1.6.0.
  o Fix --fanout command line parse bug.
* Thu Dec 11 2014 kkaempf@suse.com
- Update to 1.4.7
  o Fix typo from FRU spec, language "Tegulu" is actually "Telugu".
  o Fix typo in SEL session output, "Invalid Username of Password" to
    "Invalid Username or Password".
  o Loop on select() call if interrupted by EINTR in openipmi, ssif,
    and sunbmc inband drivers.
  o Fix integer overflow bug in ipmi-config when configure
    vlan ID > 255.
  o Add workaround for ipmi-config issue on Supermicro X10DDW-i.
  o Fix error handling bug in bmc-info.
* Wed Oct 29 2014 kkaempf@suse.com
- Update to 1.4.6
  o In ipmi-fru, support output of DDR4 SDRAM modules.
  o Fix EFI probing on non IA64 systems.
  o Fix corner case in ipmi-raw w/ standard input or --file and
    empty lines.
  o Fix parsing corner case in ipmi-chassis.
  o Support SSIF bridging.
* Fri Aug 29 2014 juwolf@suse.com
- Remove executable flags from systemd service files to prevent
  systemd warning (bnc#893142)
* Tue Jul 29 2014 kkaempf@suse.com
- Update to 1.4.5
  o Fix libipmiconsole calculation bug w/ SOL character send size.
  o Support Supermicro H8DGU and H8DG6 OEM sensors and events.
  o Minor documentation updates.
* Mon Jun 30 2014 kkaempf@localhost
- Update to 1.4.4
  o Support retrys of SSIF reads to handle SSIF NACKs.
* Thu May  8 2014 kkaempf@suse.com
- Update to 1.4.3
  has freeipmi-1.4.2.patch included, drop local patch
* Wed May  7 2014 kkaempf@suse.com
- Update to 1.4.2
  o In ipmi-oem, support Supermicro get-power-supply-status and
    get-pmbus-power-supply-status commands.
  o Support 'ipmiping' workaround in ipmipower.
  o Minor documentation updates.
- Fix compile bug, add freeipmi-1.4.2.patch
* Tue Mar  4 2014 kkaempf@suse.com
- Update to 1.4.1
  Tools - New Features
  - -------------------
  o Support 'serialalertsdeferred' workaround in ipmiconsole.
  o Support 'solpacketseq' workaround in ipmiconsole.
  o Fix portability issues for Apple / OS X.
* Thu Feb  6 2014 kkaempf@suse.com
- Drop freeipmi-max-sensor.patch, included upstream
- Update to 1.4.0 beta0
  Tools - New Features
  - -------------------
  o Support new tool ipmi-config.  Ipmi-config is a consolidated
    configuration tool implementing everything that was previously in
    bmc-config, ipmi-pef-config, ipmi-sensors-config, and
    ipmi-chassis-config.
  - The consolidated tool will allow users to checkout, commit, and
    diff sections/fields across the four former tools using only one
    tool.
  - The consolidated tool will also allow users to checkout, commit,
    and diff new sections/fields not yet covered in the four former
    tools.
  - Legacy scripts for bmc-config, ipmi-pef-config,
    ipmi-sensors-config, and ipmi-chassis-config will point to the new
    tool with all appropriate options to ensure full backwards
    compatability.
  - The ipmi-pef-config --info option has been made legacy.  It is
    still supported but no longer advertised.
  o Support Intel Data Center Host Interface / Management Engine as
    optional driver type for in-band communication.
  - Typically these are loaded as /dev/dcmi and /dev/mei drivers.
  - This driver is identified as the "inteldcmi" type, as it is
    specific to Intel systems.
  o Support OEM extensions for Intel Windmill, Wiwynn Windmill, and
    Quanta Winterfell motherboards in ipmi-sel and ipmi-sensors.  These
    motherboards are also know as motherboards for the Open Compute
    Project (OCP).
  o Support DCMI configuration in ipmi-config.
  o Update FreeIPMI for changes in IPMI 2.0 Errata 5.  Include are:
  - New sensor events for Power Supply and OS Boot sensors.  New
    events are supported in all areas, ipmi-sensors, ipmi-sel,
    libipmimonitoring, etc.
  - PEF now supports 255 filter numbers, not 127.  This is supported
    in ipmi-config (formerly ipmi-pef-config).
  - Support get/set of new System Info Parameters Present OS Version,
    BMC URL, and Base OS/Hypervisor URL.  This is supported in
    bmc-info and bmc-device.
  o Update ipmi-oem Intel Node Manager OEM commands for changes listed
    in Intelligent Power Node Manager 2.0 specification.
  - Due to changes in the specification, minor text changes may exist
    in some output from intelnm OEM commands.
  o Update ipmi-sel to support new SEL events in Intelligent Power Node
    Manager 2.0 specification.
  Tools - Bug Fixes/Minor Changes
  - ------------------------------
  o Fix bmc-info output of GUID, format was output with two bytes out of
    order.
  - May affect scripts parsing and using the GUID.
  o Bmc-info now supports --get-system-guid and outputs the System GUID
    as well as the Device GUID by default.
  - The Device GUID is not prefixed with the text "Device GUID"
    instead of just "GUID".  Any scripts scripting against this will
    need to be adjusted.
  o Bmc-info now supports a workaround of 'guidformat' to read the GUID
    with a format a number of vendors have incorrectly used.
  o In ipmi-config's sensor configuration, decimal values that cannot be
    encoded accurately now report a clearer error message.
  Libraries
  - --------
  o Update libfreeipmi and libipmimonitoring to support IPMI 2.0 Errata 5.
    Included are:
  - Support new sensor events for Power Supply and OS Boot sensors.
  - Support PEF filter numbers up to 255.
  - Support new System Info Parameters for Present OS Version, BMC
    URL, and Base OS/Hypervisor URL.
  o Update libfreeipmi to support Intel Node Manager payloads per Intel
    Intelligent Power Node Manager 2.0 specification.
  - Due to changes in the specification, some payload fields have been
    changed.
  o Update libfreeipmi SEL sub-library to handle new event messages in
    Intelligent Power Node Manager 2.0 specification.
* Wed Jan 15 2014 kkaempf@suse.com
- Updated 1.3.4 release from upstream to support ppc64le.
* Thu Dec 19 2013 kkaempf@suse.com
- Prevent crash on systems with more than 601 sensors.
  Add freeipmi-max-sensor.patch
* Fri Dec 13 2013 kkaempf@suse.com
- FreeIPMI 1.3.4 - 12/12/13
  - ------------------------
  o Support 'solchannelsupport' workraound in ipmiconsole /
    IPMICONSOLE_WORKAROUND_SKIP_CHANNEL_PAYLOAD_SUPPORT workaround
    flag in libipmiconsole.
  o Fix SDR cache workaround for motherboards with invalid SDR record
    counts listed.
  o Workaround Supermicro bug in bmc-watchdog.
  o Fix error checks in sensor decoding functions, leading to
    possible problems in ipmi-sensors-config.
  o Update documentation with additional workarounds for motherboards.
  o Fix various minor bugs.
* Wed Oct 30 2013 kkaempf@suse.com
- FreeIPMI 1.3.3
  - ------------------------
  o Add support for intelnm get-node-manager-alert-destination and
    set-node-manager-alert-destination in ipmi-oem.
  o Under very verbose mode, ipmi-sel will now record types for OEM
    records.  This should allow OEM parses outside of FreeIPMI to more
    effectively parse OEM specific SEL records.
  o Fix big endian portability bugs.
* Sun Oct 27 2013 p.drouand@gmail.com
- Add systemd support for openSUSE >= 12.3
* Fri Oct  4 2013 kkaempf@suse.com
- FreeIPMI 1.3.2 - 09/10/13
  - ------------------------
  o Update FreeIPMI tools to check libfreeipmi API error codes
    correctly.
  o Update ipmi-api.h to list mappings of IPMI completion codes and
    RMCPPlus codes to API Error codes.
* Mon Aug 26 2013 kkaempf@suse.com
- FreeIPMI 1.3.1 - 08/22/13
  Tools - New Features
  - -------------------
  o In all tools reporting time (ipmi-sel, ipmi-fru, ipmi-oem,
    bmc-device, ipmi-sensors, ipmi-dcmi), timestamps are now reporting
    under the assumption the timestamp is already in localtime (compared
    to being in UTC time and converted to localtime).  This is by
    definition in the IPMI specification.
  o In all tools reporting time (ipmi-sel, ipmi-fru, ipmi-oem,
    bmc-device, ipmi-sensors, ipmi-dcmi), support --utc-to-localtime,
  - -localtime-to-utc, and --utc-offset options to allow users to
    adjust timestamps as needed for certain environments.
  o In ipmi-fru, support output of DDR3 SDRAM modules.
  o In ipmi-fru, support output of new FRU multirecords, most notably
    extended DC output and extended DC load (per FRU Revision 1.2
    update).
  o In bmc-device, support --get-sel-time-utc-offset and
  - -set-sel-time-utc-offset.
  Tools - Bug Fixes/Minor Changes
  - ------------------------------
  o In ipmi-fru, report power supply low/high end voltage ranges as
    signed numbers (per FRU Revision 1.2 update).
  o In ipmi-fru, output "unspecified" for manufacturing date/time or
    peak capacity as appropriate (per FRU Revision 1.2 update).
  o In ipmi-fru, bridge additional FRU entries as appropriate.
  o In all tools reporting time (ipmi-sel, ipmi-fru, ipmi-oem,
    bmc-device, ipmi-sensors, ipmi-dcmi), special timestamps such as
    Post-Init and Unspecified will now be output.
  o Fix output corner case with entity sensor names in various tools.
  Libraries
  - --------
  o In libfreeipmi, support additional chassis types (per FRU Revision
    1.2 update).
  o In libfreeipmi, support new FRU multirecord types (per FRU Revision
    1.2 update).
  o In libfreeipmi, support new IPMI_FRU_FLAGS_READ_RAW 'fru'
    sub-library flag to read data from the FRU raw without parsing
    headers/records.
  o In libfreeipmi, add support for DDR3 SDRAM FRU entries and JEDEC
    manufacturer IDs.
  o In libfreeipmi, add support for Get SEL Time UTC Offset and Set SEL
    Time UTC Offset payloads.
  o In libfreeipmi 'sel' sub-library, support
    IPMI_SEL_PARAMETER_UTC_OFFSET,
    IPMI_SEL_STRING_FLAGS_UTC_TO_LOCALTIME, and
    IPMI_SEL_STRING_FLAGS_LOCALTIME_TO_UTC options/flags.
  o In libfreeipmi, do not pad legacy byte on IPMI 1.5 packets.  Legacy
    byte should be padded on ethernet frame, not IP packet.
  o In libfreeipmi, 'sdr' sub-library, when creating SDR cache, add
    checksums to cache to ensure data in cache is not corrupted.  Older
    caches without checksums still backwards compatible supported.
  o In libfreeipmi, support new IPMI_ERR_COMMAND_INVALID_OR_UNSUPPORTED
    error code for IPMI commands that are invalid or unsupported.
* Tue Jul 23 2013 kkaempf@suse.com
- FreeIPMI 1.2.9 - 07/17/13
  - ------------------------
  o Fix threshold output corner case in ipmi-sensors.
  o Fix invalid declaration in libipmimonitoring header.
  o Fix older compiler build problems.
* Mon Jun 24 2013 kkaempf@suse.com
- FreeIPMI 1.2.8 - 06/21/13
  - ------------------------
  o Fix portability build bug on ARM systems.
  o Add 'internal IPMI error' troubleshooting to manpages.
  o Fix bmc-info corner case on Bull 510 systems.
- drop automake-1_13.patch patch, included upstream
* Tue Apr 30 2013 kkaempf@suse.com
- FreeIPMI 1.2.6 - 04/29/13
  - ------------------------
  o Support HP Proliant DL160 G8 OEM sensors.
  o Support Supermicro X9SCM-iiF OEM sensors and events.
  o Support output of temperature sampling period to ipmi-dcmi.
  o Clarify error message when SOL session cannot be stolen in
    ipmiconsole/libipmiconsole.
  o Fix dcmi rolling average time period output error
  o Fix ipmi-dcmi output errors with --get-dcmi-sensor-info.
  o Fix corner case in calculation of confidentiality pad length with
    AES-CBC-128 encryption.  Incorrect pad effects some vendor firmware
    implementations.
  o Send IPMI 2.0 packets differently than IPMI 1.5 packets, as the
    former does not require legacy pad data to be appended to
    payloads.
  o Fix Intel OEM SEL buffer overflow.
  o Fix out of trunk source build.
  Libraries
  - --------
  o Support new ipmi_rmcpplus_sendto() and ipmi_rmcpplus_recvfrom()
    functions.
  o Support new HP Proliant DL160 G8 OEM sensor events.
* Thu Feb 28 2013 kkaempf@suse.com
- fix for automake 1.13
* Thu Feb 28 2013 kkaempf@suse.com
- FreeIPMI 1.2.5 - 02/26/13
  - ------------------------
  o In all config tools (bmc-config, ipmi-pef-config,
    ipmi-chassis-config, ipmi-sensors-config), fix bug when user
    specifies --checkout and --filename option and no data outputs to
    file.
  o In all config tools, exit with value 1 when non-fatal errors
    occur.
    Exit with value 2 when fatal errors occur.
  o Support Supermicro X9SPU-F-O OEM sensors and events.
  o Support Supermicro X9DRI-LN4F+ OEM intepretations (previously
    forgotten).
  o Clarify use of --filename in config tool manpages.
- FreeIPMI 1.2.4 - 01/10/12
  - ------------------------
  o Support Supermicro X9DRI-LN4F+ OEM sensors and events.
  o Fix output corner case for "session-based" channels.
  o Fix ipmi-oem set-power-restore-delay corner case in time settings.
  o Fix ipmiseld memleak.
  o Fix libfreeipmi potential fd leak when generating random numbers.
  o Fix libfreeipmi error output bug in RMCP interface.
  o Fix several minor corner cases discovered by static code analysis.
* Thu Nov 15 2012 kkaempf@suse.com
- FreeIPMI 1.2.3 - 11/14/12
  - ------------------------
  Tools
  - -----
  o In ipmi-oem, support new Dell Poweredge R720 OEM commands extensions,
    including:
  - get-nic-selection-failover
  - set-nic-selection-failover
  - power-monitoring-over-interval
  - power-monitoring-interval-range
  - get-last-post-code
  o In ipmi-oem, update active-lom-status for Dell Poweredge R720.
  o In ipmi-oem, support new Dell Poweredge R720 get-system-info option
    'cmc-info'.
  o In ipmi-oem, Dell get-system-info "slot-number" key changed to
    "blade-slot-info".  Legacy option still supported.
  o In ipmi-sel, support Dell Poweredge R720 OEM SEL extensions.
  o In all tools, support nochecksumcheck workaround option.
  o In all daemons (ipmiseld, ipmidetectd, bmc-watchdog), check for
    syscall errors during daemon setup.
  Libraries
  - --------
  o In libfreeipmi, support Dell R720 OEM extension intepretations.
  o In libfreeipmi, libipmimonitoring, and libipmiconsole, support
    NO_CHECKSUM_CHECK workaround flag.
  o In libipmiconsole, IPMICONSOLE_DEBUG_FILE logs debug to files in
    current working directory and not /var/log.  PID is also appended
    to debug files.
  Misc
  - ---
  o Various documentation updates and fixes.
* Thu Oct  4 2012 kkaempf@suse.com
- FreeIPMI 1.2.2 - 10/02/12
  Tools
  - -----
  o Support new --sol-payload-instance and --deactivate-all-instances
    options in ipmiconsole.
  o Fix ipmiseld compile issue with -Werror=format-security.
  Libraries
  - --------
  o In libipmiconsole, add new ipmiconsole_ctx_set_config() and
    ipmiconsole_ctx_get_config() functions.
  o In libipmiconsole, add support for specifying and handling
    different SOL payload instances.  This support includes:
  - Support new IPMICONSOLE_CTX_CONFIG_OPTION_SOL_PAYLOAD_INSTANCE
    configuration option.
  - In libipmiconsole, support new
    IPMICONSOLE_BEHAVIOR_DEACTIVATE_ALL_INSTANCES behavior flag.
  - Return more appropriate error codes when activation limits are
    discovered.
  o In libfreeipmi, fix debug output corner case when outputting byte
    arrays.
  Misc
  - ---
  o Various documentation updates and fixes.
* Mon Jul 30 2012 kkaempf@suse.com
- FreeIPMI 1.1.7 - 07/30/12
  o In ipmi-sensors and ipmi-sel, fix units output corner case.
  o In bmc-info, detect unsupported system info corner case.
  o Update documentation with motherboard support.
  Special Note: This will likely be the last release of FreeIPMI
  in the 1.1.X stable branch.
* Wed Jul  4 2012 kkaempf@suse.com
- Fix build: %%make_install -> %%makeinstall
* Fri Jun 29 2012 kkaempf@suse.com
- FreeIPMI 1.1.6 - 06/28/12
  - Tools
  - -----
  o In ipmi-sel, support Supermicro SEL OEM interpretations in
  - -output-event-state.
  o In ipmi-sel and ipmi-sensors, support additional sensor/SEL
    interpretations including:
  - Version Change
  - System Firmware Progress Transition Severity
  - Button/Switch Transition Severity
  - Chassis Transition Severity
  - POST Memory Resize State
  - Cable/Interconnect Transition Severity
  - Boot Error Transition Severity
  - Slot Connector Transition Severity
  - Memory State
  - Memory Transition Severity
  o In bmc-config, ipmi-chassis-config, ipmi-pef-config, and
    ipmi-chassis-config, support cipher suite ID argument.
  o Support Supermicro X9DRi-F OEM sensors and events.
  o Fix Intel S2600JF/Appro 512x OEM SEL interpretations based on
    comments from Intel.
  Libraries
  - --------
  o Support Supermicro SEL OEM interpretations.
  o Support new sensor/SEL interpretations.
  Misc
  - ---
  o Various documentation updates and fixes.
* Thu May 17 2012 kkaempf@suse.com
- FreeIPMI 1.1.5 - 05/17/12
  Tools
  - -----
  o Support Supermicro OEM sensors/SEL on H8DGU-F motherboards.
  o In ipmiconsole, fix password length check bug.
  o In bmc-watchdog, fix --start-if-stopped and --reset-if-running
    options.
  o In ipmidetectd, fix usage output typos.
  o In ipmi-sensors-config, fix several parallel output corner cases.
  o For consistency to other tools, turn on quiet-caching if
    communicating with multiple hosts in bmc-device and ipmi-oem.
  o In ipmi-sensors, fix bug in which multiple workarounds could not
    be used or used in combination with bridging.
  o Fix start run levels in ipmidetectd init script.
  Libraries
  - --------
  o In libfreeipmi fru-parse API, handle additional device busy errors.
  Misc
  - ---
  o Various documentation updates.
* Tue May  8 2012 trenn@suse.de
- Fix build: Added version 1.1.4 tarball
- Adjust specfile according to spec-cleaner as suggested by Sascha Peilicke
  to get this package into factory.
* Fri Apr 20 2012 kkaempf@suse.com
- FreeIPMI 1.1.4 - 04/19/12
  Tools
  - -----
  o In ipmi-oem, fix error message output in several Supermicro OEM
    commands.
  o In ipmi-oem, add Intel --get-power-restore-delay and
  - -set-power-restore-delay support.
  o In ipmi-sel, support Intel S2600JF/Appro 512x OEM SEL
    interpretations.
  Libraries
  - ---------
  o In libfreeipmi, support new sensor and SEL event
    interpretations, including Session Audit, Voltage Limits.
  o In libfreeipmi, support new OEM interpretations for Intel S5000PAL
    NMI State and SMI timeout sensors/SEL events.
  o In libfreeipmi, support Intel S2600JF/Appro 512x OEM SEL
    interpretations.
  Misc
  - ---
  o Various documentation updates.
* Fri Mar 23 2012 trenn@suse.de
- Adjust source url, downloadable tarballs moved from zresearch
  to ftp.gnu.org
- Update to 1.1.3
* Mon Mar 19 2012 trenn@suse.de
- Adjust .spec file via format_spec_file
* Tue Mar  6 2012 trenn@suse.de
- Update to 1.1.2
- Adjusted license to GPL-3.0
- Silent some build checks:
  - license string
  - too short description
  - remove INSTALL file from %%docdir
* Wed Sep 21 2011 kkaempf@suse.com
- Update to 1.0.6
  o Support 'ignorescanningdisabled' workaround in ipmi-sensors.
  o Support Supermicro X8SIL-F, X9SCL, and X9SCM motherboard OEM sensors.
  o Update bmc-watchdog logrotate script to reduce unnecessary output.
  o Fix ipmi-fru output typo.
- Update to 1.0.5
  o Fix various issues in ipmi-dcmi, including command line parsing
    bugs, asset tag/string identifier overwriting, and fix assumptions
    based on new information in v1.5 errata.
  o Support pkg-config files for libraries.
  o Various documentation updates.
* Sat Apr 23 2011 kkaempf@novell.com
- Update to 1.0.4
  o Support "discretereading" workaround in ipmi-sensors and
    associated libraries.
  o Support "spinpoll" workaround/performance optimization in tools
    and libraries.
  o Support additional sensor/SEL interpretations for Intel
    motherboards.
  o Add convenience input checking functions to libipmiconsole.
  o Fix bug in libipmimonitoring to allow additional OEM
    interpretations.
* Wed Mar 30 2011 kkaempf@novell.com
- update to 1.0.3
  o Support additional error handling in bmc-info.
  o Support ability to set "none" workaround flags on the command
    line and in tools.
  o In libipmiconsole, force ipmiconsole_engine_init() to be
    called before ipmiconsole_ctx_create().
  o Fix libipmiconsole callback semantics.
  o Fix libipmiconsole bugs in overriding standard defaults vs.
    config file defaults.
  o Fix potential race in libipmiconsole during engine teardown.
  o Add package version macros to libfreeipmi.
  o Add library version macros to all libraries.
  o Fix Solaris build bug.
  o Fix config output bug in ipmipower.
- update to 1.0.2
  o Support --ignore-unrecognized-events in ipmi-sensors.
  o Clarify error messages in ipmi-locate.
  o Support Supermicro X7DBR-3, X8DTL-3F, X8DT3-LN4F motherboard OEM
    sensors.
  o Support Dell Module/Board OEM sensor interpretation on Poweredge
    R210 motherboards.
  o In bmc-info, support motherboards that don't implement Get Device
    Guid.
  o In bmc-watchdog, fix error logging corner case.
  o Support new -r option in ganglia_ipmi_sensors.pl plugin to modify
    ipmi hostname.
  o Add workaround for SDR caching compliance bug in HP Proliant
    DL585G7.
  o In bmc-config, add workaround for motherboards that do not allow
    you to configure identical usernames.
  o Various documentation updates.
- update to 1.0.1
  o Remove ipmimonitoring tool. Tool is now superseded by ipmi-sensors
    and the new --output-sensor-state option.
  o Support --output-event-state option for ipmi-sel to support SEL
    event interpretation.
  o All config-tools now support multi-channel configuration under
    verbose mode.
  o Re-architect libipmimonitoring to support all defined IPMI sensor
    types, OEM bitmasks, and OEM interpretations.
  o Add SEL monitoring support to libipmimonitoring.
  o Support new 'interpret' sub-library in libfreeipmi.
  o Support interpretation rules for sensors when no states/events occur.
  o Support interpretation rules for out of spec sensor states/events.
  o Support interpretation rules for OEM sensors and events.
  o Move all config files to /etc/freeipmi/. Support legacy config
    files for backwards compatibility.
  o Support serial keepalive in ipmiconsole to check if serial
    connection has remained alive across system reboots.
  o Create symlinks and manpage pointers for 'ipmi-power', 'ipmi-ping',
    'rmcp-ping', 'ipmi-console', and 'ipmi-detect' to give some additional
    consistency to the tool naming.
  o Various documentation updates.
  o Update to support DCMI 1.1.
  o Update all licensing information to GPLv3.
- update to 0.8.12
  o In bmc-config, workaround RMCP+ Privilege Level configuration
    compliance bugs on HP DL145 servers.
  o In ipmi-chassis-config, after configuring boot flags, set valid bits
    appropriately.
  o Fix N/A output corner case in ipmi-sel.
  o Support Supermicro X8DTU-6+ motherboard OEM sensors.
  o Fix FRU date/time calculation bug that did not account for leap
    years.
- update to 0.8.11
  o Support Fujitsu iRMC S1 and iRMC S2 OEM extensions in
    ipmi-sensors and ipmi-sel.
  o Support --output-oem-event-string in ipmi-sel.
  o Other minor documentation/bug fixes.
- update to 0.8.10
  o Support many new Inventec OEM extensions in ipmi-oem.
  o Support many new Quanta OEM extensions in ipmi-oem.
  o Support many new Intel OEM extensions in ipmi-oem.
  o Support Intel s5500WB OEM extensions in ipmi-sel.
  o Support Intel Node Manager SEL events across Quanta S99Q,
    Inventec 5441, Inventec 5442, and Intel S5500WB motherboards.
  o Move some OEM extensions from Dell section to Inventec section in
    ipmi-oem. Were previously thought to be additions by Dell, but
    in fact are not. Backwards compatability supported.
  o Support 'assumeio' inband workaround globally.
  o Gracefully handle some errors in ipmi-sensors.
  o Fix in-band probing corner case.
  o Fix various parameter input checks in ipmi-oem.
  o Fix help output corner cases in ipmi-oem.
  o Other minor documentation/bug fixes.
- update to 0.8.9
  o In ipmi-sel and ipmimonitoring, workaround Supermicro H8QME SEL
    compliance issues in ipmi-sel.
  o In ipmi-sel, do not report error if SEL is empty.
  o Support Fujitsu 'get-sel-entry-long-text' in ipmi-oem.
  o Fix workaround flags bug in ipmimonitoring.
  o Revert 'Open Session Privilege Workaround' changes in 0.8.8, were
    unnecessary.
  o Fix daylight savings bug when configuring BMC times in bmc-device.
  o Support 'veryslowcommit' workaround for config tools to work around
    very slow BMCs.
  o Support --enable-rawdumps compile option.
  o Support SHA256 in IPMI 2.0.
  o Other minor bug fixes.
- update to 0.8.8
  o Support Supermicro 'get-bmc-services-status' and
    'set-bmc-services-status' in ipmi-oem.
  o Support bmc-watchdog 'ignorestateflag' workaround around more
    issues.
  o Support Open Session Privilege Workaround around more related
    compliance issues.
  o Fix bmc-watchdog --version option.
  o Fix legacy workaround corner case in channel detection for
    Intel nodes.
  o Support Quanta reset-to-defaults command in ipmi-oem.
  o Modify ipmiconsole protocol to not deactivate SOL protocol is
    SOL is already deactivated.
  o Modify ipmiconsole protocol to not error out under several
    malformed packet scenarios.
  o Fix ipmiping/rmcpping command line parsing corner case.
  o Minor documentation updates.
  o Minor error message output fixes.
  o Support --without-random-device configure option for some
    embedded systems.
- update to 0.8.7
  o Support Supermicro X8DTG OEM sensors.
  o Support Supermicro X8DTG workarounds with 'integritycheckvalue'
    workaround flag.
  o Document workarounds for Intel S5500WBV/Penguin Relion 700
    motherboard.
  o Map IPMI 2.0 "invalid role" error code to "privilege level cannot be
    obtained" for better usability.
  o Fix bmc-config Security Keys commit by making some required fields
    optional.
  o Fix bmc-watchdog init script return codes on Suse.
  o Support 'ignorestateflag' workaround in bmc-watchdog.
  o Fix ipmi-sensors corner case for sensors with percentage units.
  o Support 'slowcommit' workaround for config tools to work around
    slower BMCs.
  o Update documentation w/ Supermicro X8DTG issues.
  o Update documentation w/ inband troubleshooting.
- update to 0.8.6
  o Support Quanta S99Q/Dell FS12-TY OEM SEL events.
  o In ipmi-oem, support Quanta S99Q/Dell FS12-TY OEM commands.
  o Fix --key-pair parsing bug in all config tools.
  o Locally support sunbmc driver if bmc_intf.h header not found.
  o If Sunbmc driver is not supported, report "Device Not Supported"
    instead of "Internal Error".
  o Fix error output messages.
  o Fix Solaris install issue.
  o Other minor fixes.
* Fri Apr 30 2010 kkaempf@novell.com
- update to 0.8.5
  - Support Inventec 5442/Dell Xanadu III OEM events.
  - Workaround Quanta S99Q/Dell FS12-TY Node Busy errors.
  - Fix some library error checks limiting bmc-config Bad Password
    Threshold configuration.
  - Fix some library macro names based on actual OEM names.
  - Fix documentation typos.
  (update to 0.8.4)
  - Fix IPMI 2.0 sequence number wrap around corner case.
  - Fix ipmi-sensors --comma-separated-output corner case.
  - In ipmi-sensors, output multiple event strings w/ space
    delimiter in simple output.
  - In ipmi-oem, support Dell get-active-lom-status.
  - In ipmi-oem, support IBM get-led.
  - In ipmi-sel, fix possible --assume-system-event-records
    corner case.
  - Fix Posix portability issue w/ time functions.
  - Minor documentation updates.
* Wed Feb  3 2010 kkaempf@novell.com
- update to 0.8.3
  - fix buffer overflow (was: ipmi-messaging-support-cmds.patch)
* Thu Jan 14 2010 kkaempf@novell.com
- adapt_to_suse_docdir.patch: Use /usr/share/doc/packages/$(name)
- add_default_start.patch: Add 'Default-Start:' to init.d scripts
- ipmi-messaging-support-cmds.patch: Fix buffer overflow
* Thu Jan 14 2010 kkaempf@novell.com
- Update to 0.8.2
